
*--------reformat and clean the variables--------*

clear
import excel 	using "${dofile_dir}/20200930-cois-responseclean.xlsx", ///
sheet("import-to-stata") firstrow case(lower)
compress

//For q1-3 , 28, 35 & 40 
//Clean up the responses by replacing certain texts with standardized texts 
//To see the original response and what is replaced, see excel spreadsheet 

foreach n of numlist 1/3 28 35 40 {
do "${dofile_dir}/replaceq`n'.do"
}

//Encode q1-q2
foreach x of varlist q2{
encode `x', generate(`x'_recode) label("`x'")
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}

//Encode q3 and q5		

label define q3q5		///
1	"South Africa"	///
2	"Zambia"	///
3	"United Kingdom"	///
4	"Sweden"	///
5	"Germany"	///
6	"Netherlands"	///
7	"Canada"	///
8	"Russia"	///
9	"New Zealand"	///
99	"Not practicing "	

foreach x of varlist q3 q5{
encode `x', generate(`x'_recode) label(q3q5) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}

//For q4		
label define q4		///
4	"More than 20 years"	///
3	"11 - 20 years"	///
1	"Less than 5 years"	///
2	"5 - 10 years"

encode q4, generate(q4_recode) label(q4) noextend
order q4_recode, before(q4)
drop q4
rename q4_recode q4


//For q7-q16

label define q7q16		    ///
1	"Never"	    ///
2	"Occasionally"	    ///
3	"Sometimes"	    ///
4	"Often"	    ///
5	"Always"	    ///
99	"Don't know or can't answer"	

forvalues n = 7/16{
encode q`n', generate(q`n'_recode) label(q7q16) noextend 
quietly{
count if q`n' != ""
local n1 = r(N)
count if q`n'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order q`n'_recode, before(q`n')
drop q`n'
rename q`n'_recode q`n'

}	

//For q17	

label define q17		    ///
1	"Never"	    ///
2	"Rarely"	    ///
3	"Sometimes"	    ///
4	"Frequently"	    ///
5	"Very frequently"	    ///
99	"Don't know/can't answer"	

foreach x of varlist q17*{
encode `x', generate(`x'_recode) label(q17) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}


//For q20 q22	

label define 	likely	///
1	"Very unlikely"	///
2	"Unlikely"	///
3	"Neither unlikely nor likely"	///
4	"Somewhat likely"	///
5	"Very likely"	///
99	"Don't know or can't answer"	



foreach x of varlist q20 q22{
encode `x', generate(`x'_recode) label(likely) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}		


//For q21

forvalues i = 1/7{
gen q21_ans`i' = 0 if q21 != "" & q21 != "N/A"   
}

replace q21_ans1 = 1 if strpos(q21,"implicate")>0
replace q21_ans2 = 1 if strpos(q21,"how to report")>0
replace q21_ans3 = 1 if strpos(q21,"difficult to prove")>0
replace q21_ans4 = 1 if strpos(q21,"make a difference")>0
replace q21_ans5 = 1 if strpos(q21,"burdensome")>0
replace q21_ans6 = 1 if strpos(q21,"afraid of negative consquences")>0
replace q21_ans7 = 1 if strpos(q21,"normal")>0


order q21_ans1-q21_ans7, after(q21)

rename q21 q21_allanswers

//For q28

replace q28 = "" if q28 == "xx"

//For q19; q29-q34; q38; q42-50; q52_statement1-q52_statement2		

label define 	agreeable	///
1	"Strongly agree"	///
2	"Agree"	///
3	"Somewhat agree"	///
4	"Neither agree nor disagree"	///
5	"Somewhat disagree"	///
6	"Disagree"	///
7	"Strongly disagree"	

foreach x of varlist q19 q29-q34 q38 q42-q50  q52_statement1-q52_statement2{
replace `x' = "Neither agree nor disagree" if `x' == "Neither agree no disagree"
replace `x' = "Somewhat agree" if `x' == "Somewhate agree"
replace `x' = "Strongly agree" if `x' == "Strongly Agree"
encode `x', generate(`x'_recode) label(agreeable) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}		


//For q24-26; q53; q57; q59_activity1-q59_activity5		

label define 	yesno	///
2	"No"	///
1	"Yes"	///
88	"Prefer not to answer"	///
99	"Don't know"	///
77	"Don't know or can't answer"	

foreach x of varlist q24-q26  q53 q57 q59_activity1-q59_activity5	{
encode `x', generate(`x'_recode) label(yesno) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	
//For q27: 
forvalues n = 1/6{
gen q27_ans`n'= 0 if q27 != ""
}

replace q27_ans1 = 1 if strpos(q27,"Co-workers")>0
replace q27_ans2 = 1 if strpos(q27,"Family")>0
replace q27_ans3 = 1 if strpos(q27,"Superior")>0
replace q27_ans4 = 1 if strpos(q27,"colleague")>0
replace q27_ans5 = 1 if strpos(q27,"Religio")>0
replace q27_ans6 = 1 if strpos(q27,"myself")>0

order q27_ans*, after(q27)

rename q27 q27_allanswers

//For q36	

label define q36		///
1	"Decreased a lot"	///
2	"Decreased somewhat"	///
3	"Stayed the same"	///
4	"Increased somewhat"	///
5	"Increased a lot"	


encode q36, generate(q36_recode) label(q36) noextend 
order q36_recode, after(q36)
drop q36
rename  q36_recode q36


//For q37	

label define q37		///
5	"Very corrupt"	///
4	"Somewhat corrupt"	///
3	"Neither corrupt nor clean"	///
2	"Somewhat clean"	///
1	"Very clean"	

foreach x of varlist q37* {
encode `x', generate(`x'_recode) label(q37) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	

//For q39		
label define q39		///
1	"Never justifiable"	///
2	"Sometimes justifiable"	///
3	"Justifiable in exceptional circumstances"	

encode q39, generate(q39_recode) label(q39) noextend
order q39_recode, after(q39)
drop q39
rename q39_recode q39

//For q54: 
forvalues n = 1/5{
gen q54_ans`n' = 0 if q54!= ""
}
replace q54_ans1 = 1 if strpos(q54,"Government, ")>0 | q54 == "Government"
replace q54_ans2 = 1 if strpos(q54,"Government authorized") > 0 
replace q54_ans3 = 1 if strpos(q54,"Private professional") > 0 
replace q54_ans4 = 1 if strpos(q54,"Work firm, office, or department") > 0 
replace q54_ans5 = 1 if strpos(q54,"Don't know") > 0 


order q54_ans*, after(q54)

rename q54 q54_allanswers


//For q60_age

label define age		///
5	"Older than 60"	///
2	"30 - 39"	///
1	"20 - 29"	///
3	"40 - 49"	///
4	"50 - 60"	
replace q60_age = "50 - 60" if q60_age == "50 -60"
encode q60_age, generate(age) label(age) noextend 
drop q60_age 
order age, after(timestamp)

//For q61_gender		

label define gender 		///
1	"Female"	///
2	"Male"	///
3	"Non-binary"	

encode q61_gender, generate(gender) label(gender) noextend 
drop q61_gender 
order gender, after(age)


//For q51_atttribute1-q51_atttribute8		

label define attribute		///
1	"Very important"	///
2	"Important"	///
3	"Less important"	///
4	"Not important at all"	///
99	"Don't know or can't answer"	

foreach x of varlist q51* {
encode `x', generate(`x'_recode) label(attribute) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	


//For q55		

label define useful		///
1	"Very useful"	///
2	"Somewhat useful"	///
3	"Not so useful"	///
4	"Not useful at all"	///
99	"Don't know or can't answer"	

encode q55, generate(q55_recode) label(useful) noextend 
order q55_recode, after(q55)
drop q55
rename  q55_recode q55

//For q58 
forvalues i = 1/5{
gen q58_ans`i' = 0 if q58 != "" & q58 != "none"
}

replace q58_ans1 = 1 if strpos(q58, "ethics and integrity")>0
replace q58_ans2 = 1 if strpos(q58, "code of conduct")>0
replace q58_ans3 = 1 if strpos(q58, "whistle")>0
replace q58_ans4 = 1 if strpos(q58, "bad behaviour")>0
replace q58_ans5 = 1 if strpos(q58, "ost discussion")>0

order q58_ans*, after(q58)

rename q58 q58_allanswers
