clear all 
cd "/Users/Sammy/Desktop/Cities of Integrity Survey"

*--------make replacement do files--------*

import excel 	using "rawdata/20200930-cois-responseclean.xlsx", ///
sheet("codebook") firstrow case(lower)

//Make do files for replacing values. See below

foreach n of numlist 1/3 28 35 40 {

gen strL replaceq`n' = 	`"replace q`n' "' +  `" = ""' + q`n'_replace ///
+ `"" if q`n'== ""' + q`n' + `"""' if q`n'_replace!="" & q`n'!=""

outfile replaceq`n' using "dofiles/replaceq`n'.do", replace noquote	

}

*--------reformat and clean the variables--------*

clear
import excel 	using "rawdata/20200930-cois-responseclean.xlsx", ///
sheet("import-to-stata") firstrow case(lower)
compress

//For q1-3 , 28, 35 & 40 
//Clean up the responses by replacing certain texts with standardized texts 
//To see the original response and what is replaced, see excel spreadsheet 

foreach n of numlist 1/3 28 35 40 {
do "dofiles/replaceq`n'.do"
}

//Encode q1-q2
foreach x of varlist q2{
encode `x', generate(`x'_recode) label("`x'")
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}

//Encode q3 and q5		

label define q3q5		///
1	"South Africa"	///
2	"Zambia"	///
3	"United Kingdom"	///
4	"Sweden"	///
5	"Germany"	///
6	"Netherlands"	///
7	"Canada"	///
8	"Russia"	///
9	"New Zealand"	///
99	"Not practicing "	

foreach x of varlist q3 q5{
encode `x', generate(`x'_recode) label(q3q5) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}

//For q4		
label define q4		///
4	"More than 20 years"	///
3	"11 - 20 years"	///
1	"Less than 5 years"	///
2	"5 - 10 years"

encode q4, generate(q4_recode) label(q4) noextend
order q4_recode, before(q4)
drop q4
rename q4_recode q4


//For q7-q16

label define q7q16		    ///
1	"Never"	    ///
2	"Occasionally"	    ///
3	"Sometimes"	    ///
4	"Often"	    ///
5	"Always"	    ///
99	"Don't know or can't answer"	

forvalues n = 7/16{
encode q`n', generate(q`n'_recode) label(q7q16) noextend 
quietly{
count if q`n' != ""
local n1 = r(N)
count if q`n'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order q`n'_recode, before(q`n')
drop q`n'
rename q`n'_recode q`n'

}	

//For q17	

label define q17		    ///
1	"Never"	    ///
2	"Rarely"	    ///
3	"Sometimes"	    ///
4	"Frequently"	    ///
5	"Very frequently"	    ///
99	"Don't know/can't answer"	

foreach x of varlist q17*{
encode `x', generate(`x'_recode) label(q17) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}


//For q20 q22	

label define 	likely	///
1	"Very unlikely"	///
2	"Unlikely"	///
3	"Neither unlikely nor likely"	///
4	"Somewhat likely"	///
5	"Very likely"	///
99	"Don't know or can't answer"	



foreach x of varlist q20 q22{
encode `x', generate(`x'_recode) label(likely) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}		


//For q21

forvalues i = 1/7{
gen q21_ans`i' = 0 if q21 != "" & q21 != "N/A"   
}

replace q21_ans1 = 1 if strpos(q21,"implicate")>0
replace q21_ans2 = 1 if strpos(q21,"how to report")>0
replace q21_ans3 = 1 if strpos(q21,"difficult to prove")>0
replace q21_ans4 = 1 if strpos(q21,"make a difference")>0
replace q21_ans5 = 1 if strpos(q21,"burdensome")>0
replace q21_ans6 = 1 if strpos(q21,"afraid of negative consquences")>0
replace q21_ans7 = 1 if strpos(q21,"normal")>0


order q21_ans1-q21_ans7, after(q21)

rename q21 q21_allanswers

//For q28

replace q28 = "" if q28 == "xx"

//For q19; q29-q34; q38; q42-50; q52_statement1-q52_statement2		

label define 	agreeable	///
1	"Strongly agree"	///
2	"Agree"	///
3	"Somewhat agree"	///
4	"Neither agree nor disagree"	///
5	"Somewhat disagree"	///
6	"Disagree"	///
7	"Strongly disagree"	

foreach x of varlist q19 q29-q34 q38 q42-q50  q52_statement1-q52_statement2{
replace `x' = "Neither agree nor disagree" if `x' == "Neither agree no disagree"
replace `x' = "Somewhat agree" if `x' == "Somewhate agree"
replace `x' = "Strongly agree" if `x' == "Strongly Agree"
encode `x', generate(`x'_recode) label(agreeable) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}		


//For q24-26; q53; q57; q59_activity1-q59_activity5		

label define 	yesno	///
2	"No"	///
1	"Yes"	///
88	"Prefer not to answer"	///
99	"Don't know"	///
77	"Don't know or can't answer"	

foreach x of varlist q24-q26  q53 q57 q59_activity1-q59_activity5	{
encode `x', generate(`x'_recode) label(yesno) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	
//For q27: 
forvalues n = 1/6{
gen q27_ans`n'= 0 if q27 != ""
}

replace q27_ans1 = 1 if strpos(q27,"Co-workers")>0
replace q27_ans2 = 1 if strpos(q27,"Family")>0
replace q27_ans3 = 1 if strpos(q27,"Superior")>0
replace q27_ans4 = 1 if strpos(q27,"colleague")>0
replace q27_ans5 = 1 if strpos(q27,"Religio")>0
replace q27_ans6 = 1 if strpos(q27,"myself")>0

order q27_ans*, after(q27)

rename q27 q27_allanswers

//For q36	

label define q36		///
1	"Decreased a lot"	///
2	"Decreased somewhat"	///
3	"Stayed the same"	///
4	"Increased somewhat"	///
5	"Increased a lot"	


encode q36, generate(q36_recode) label(q36) noextend 
order q36_recode, after(q36)
drop q36
rename  q36_recode q36


//For q37	

label define q37		///
5	"Very corrupt"	///
4	"Somewhat corrupt"	///
3	"Neither corrupt nor clean"	///
2	"Somewhat clean"	///
1	"Very clean"	

foreach x of varlist q37* {
encode `x', generate(`x'_recode) label(q37) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	

//For q39		
label define q39		///
1	"Never justifiable"	///
2	"Sometimes justifiable"	///
3	"Justifiable in exceptional circumstances"	

encode q39, generate(q39_recode) label(q39) noextend
order q39_recode, after(q39)
drop q39
rename q39_recode q39

//For q54: 
forvalues n = 1/5{
gen q54_ans`n' = 0 if q54!= ""
}
replace q54_ans1 = 1 if strpos(q54,"Government, ")>0 | q54 == "Government"
replace q54_ans2 = 1 if strpos(q54,"Government authorized") > 0 
replace q54_ans3 = 1 if strpos(q54,"Private professional") > 0 
replace q54_ans4 = 1 if strpos(q54,"Work firm, office, or department") > 0 
replace q54_ans5 = 1 if strpos(q54,"Don't know") > 0 


order q54_ans*, after(q54)

rename q54 q54_allanswers


//For q60_age

label define age		///
5	"Older than 60"	///
2	"30 - 39"	///
1	"20 - 29"	///
3	"40 - 49"	///
4	"50 - 60"	
replace q60_age = "50 - 60" if q60_age == "50 -60"
encode q60_age, generate(age) label(age) noextend 
drop q60_age 
order age, after(timestamp)

//For q61_gender		

label define gender 		///
1	"Female"	///
2	"Male"	///
3	"Non-binary"	

encode q61_gender, generate(gender) label(gender) noextend 
drop q61_gender 
order gender, after(age)


//For q51_atttribute1-q51_atttribute8		

label define attribute		///
1	"Very important"	///
2	"Important"	///
3	"Less important"	///
4	"Not important at all"	///
99	"Don't know or can't answer"	

foreach x of varlist q51* {
encode `x', generate(`x'_recode) label(attribute) noextend 
quietly{
count if `x' != ""
local n1 = r(N)
count if `x'_recode != .
local n2 = r(N)
}
assert `n1' == `n2'
order `x'_recode, before(`x')
drop `x'
rename `x'_recode `x'
}	


//For q55		

label define useful		///
1	"Very useful"	///
2	"Somewhat useful"	///
3	"Not so useful"	///
4	"Not useful at all"	///
99	"Don't know or can't answer"	

encode q55, generate(q55_recode) label(useful) noextend 
order q55_recode, after(q55)
drop q55
rename  q55_recode q55

//For q58 
forvalues i = 1/5{
gen q58_ans`i' = 0 if q58 != "" & q58 != "none"
}

replace q58_ans1 = 1 if strpos(q58, "ethics and integrity")>0
replace q58_ans2 = 1 if strpos(q58, "code of conduct")>0
replace q58_ans3 = 1 if strpos(q58, "whistle")>0
replace q58_ans4 = 1 if strpos(q58, "bad behaviour")>0
replace q58_ans5 = 1 if strpos(q58, "ost discussion")>0

order q58_ans*, after(q58)

rename q58 q58_allanswers


*--------label all variables--------*

//Variables derived from the answers: Not in the excel sheet
label variable q21_ans1 "Answered: Would be implicated"
label variable q21_ans2 "Answered: Do not know where and how to report"
label variable q21_ans3 "Answered: Corruption too difficult to prove"
label variable q21_ans4 "Answered: Wouldn't make a difference"
label variable q21_ans5 "Answered: Reporting is burdensome/expensive"
label variable q21_ans6 "Answered: Afraid of negative consequences"
label variable q21_ans7 "Answered: Corruption is normal"

label variable q27_ans1 "Answered: Co-workers"
label variable q27_ans2 "Answered: Family or friends"
label variable q27_ans3 "Answered: Superior"
label variable q27_ans4 "Answered: Colleagues or mentors from professional group"
label variable q27_ans5 "Answered: Religious leader"
label variable q27_ans6 "Answered: No one - I work it out myself"

label variable q37_corrupt1 "How clean/corrupt are: Local politicians"
label variable q37_corrupt2 "How clean/corrupt are: National/provincial politicians"
label variable q37_corrupt3 "How clean/corrupt are: Senior officials in local government"
label variable q37_corrupt4 "How clean/corrupt are: Senior officials in national/provincial government"
label variable q37_corrupt5 "How clean/corrupt are: Developers"
label variable q37_corrupt6 "How clean/corrupt are: Other planners"

label variable q54_ans1 "Answered: Government"
label variable q54_ans2 "Answered: Government authorized professional associations"
label variable q54_ans3 "Answered: Private professional association"
label variable q54_ans4 "Answered: Work firm, office or department"
label variable q54_ans5 "Answered: Don't know or can't answer"

label variable q58_ans1 "Answered: Provide training on ethics and integrity for practicing planners"
label variable q58_ans2 "Answered: Develop and promote a good code of conduct"
label variable q58_ans3 "Answered: Support whistle-blowers"
label variable q58_ans4 "Answered: Discipline bad behaviours"
label variable q58_ans5 "Answered: Host discussions about values in planning and how to develop them further"

//All the variables from the original dataset: in the excel sheet
label variable	age	"What is your age?"
label variable	gender	"What is your gender?"
label variable	q1	"In which field have you been trained?"
label variable	q2	"What is your highest level of education?"
label variable	q3	"Where did your highest professional planning training take place?"
label variable	q4	"How long have you worked in the urban development sector?"
label variable	q5	"In which country are you currently primarily practicing?"
label variable	q6	"In what sector are you currently working (check all that apply)?"
label variable	q7	"How often at work are you asked to ignore or violate rules, policies, or procedures in order to achieve a particular planning outcome?"
label variable	q8	"How often at work are you required to use your expertise to manufacture pre-ordained outcomes that benefit particular officials or private parties?"
label variable	q9	"How often at work do you believe you will be demoted, reassigned, or otherwise penalized professionally for performing your work ethically?"
label variable	q10	"Do you ever feel that you are being physically or emotionally threatened for performing your work in an ethical manner?"
label variable	q11	"How often at work do developers or other interested parties offer you money or other favours illicitly in return for taking a particular action in their favour"
label variable	q12	"How often at work are infrastructure projects intentionally directed towards benefiting particular officials or private parties?"
label variable	q13	"How often at work are public contracting and procurement rules not properly followed or enforced for the benefit of particular individuals or private parties?"
label variable	q14	"How often at work do colleagues, superiors or senior officials with active planning oversight have a monetary or personal interest in planning outcomes"
label variable	q15	"Do you ever find yourself in a position where you are working on two sides of a matter at the same time"
label variable	q16	"How often: Public consultations are token exercises and their outcomes are largely irrelevant to the final planning decision"
label variable	q17_issue1	"Issue: [Too little time/resources]"
label variable	q17_issue2	"Issue: [No support from management or colleagues]"
label variable	q17_issue3	"Issue: [No support from public or private clients]"
label variable	q17_issue4	"Issue: [Issues with other public bodies/processes]"
label variable	q17_issue5	"Issue: [Difficult/unclear planning laws]"
label variable	q17_issue6	"Issue: [Language barriers or cultural differences]"
label variable	q18	"Issues not listed in Q17"
label variable	q19	"Agree or disagree: My professional training has equipped me with the adequate knowledge and skills to understand and address corruption and ethical issues in urban development"
label variable	q20	"How likely is it that urban planners or other urban development practitioners report corruption or other ethical problems that they experience in their work?"
label variable	q21_allanswers	"If you responded unlikely or very unlikely to the previous question, please specify up to three reasons why YOU believe this to be the case:"
label variable	q22	"How likely is it that YOU would be willing to report an incident of corruption at work?"
label variable	q23	`"If you responded "Somewhat likely" or "Very likely" to the previous question, to whom would you report corruption (name up to two)?"'
label variable	q24	"Have you reported an incident of corruption or ethical failing in your work before?"
label variable	q25	"If you responded Yes to Question 24, was it followed up properly and effectively?"
label variable	q26	"If you responded Yes to Question 24, did you experience negative consequences?"
label variable	q27_allanswers	"When you are confronted with an ethical dilemma in performing your job, who do you usually turn to for support? Check all that apply"
label variable	q28	"Who do you turn to the most?"
label variable	q29	"Agree or disagree: Applicable rules and regulations in urban development are largely unfair and give too much influence to powerful interests"
label variable	q30	"Agree or disagree: Land is frequently being illegally appropriated by powerful interests with impunity"
label variable	q31	"Agree or disagree: Local government is run by a few big players looking out for themselves"
label variable	q32	"Agree or disagree: Public consultation and participation are very often just for show and do not influence plans and projects"
label variable	q33	"Agree or disagree: Public officials often have conflicts of interest due to their private activities or relationships"
label variable	q34	"Agree or disagree: There is a lack of disclosure regarding the financial or personal interest private sector planners have in the projects they work on"
label variable	q35	"Who is benefitting most from urban development programmes?"
label variable	q36	"Over the past year, the level of corruption in urban development has:"
label variable	q38	"Agree or disagree: Small bribes do not do much harm, they just help to grease the wheels of a complex administrative system"
label variable	q39	"Accepting a bribe while executing one’s duties is:"
label variable	q40	"Is it ok for someone to work on two sides of a matter"
label variable	q41	"How ethical do you consider yourself in comparison to your peers?"
label variable	q42	"Agree or disagree: Making a difference in society means more to me than personal achievements"
label variable	q43	"Agree or disagree: I believe in putting duty before self"
label variable	q44	"Agree or disagree: I wanted to become a planner because I wanted to serve the public"
label variable	q45	"Agree or disagree: There should be tighter controls on private developments to protect the public interest"
label variable	q46	"Agree or disagree: Planners should primarily focus on developing technically correct solutions to planning problems"
label variable	q47	"Agree or disagree: Planners are trained to anticipate the needs of local communities"
label variable	q48	"Agree or disagree: Planners should work within the rules of their firm/department even if they do not always agree with them"
label variable	q49	"Agree or disagree: The planner's job is to assist in achieving their client's objectives"
label variable	q50	"Agree or disagree: I wanted to become a planner because I am interested in shaping the physical environment around me"
label variable	q51_attribute1	"Importance of [Technical expertise]"
label variable	q51_attribute2	"Importance of [Ability to follow orders]"
label variable	q51_attribute3	"Importance of [Integrity]"
label variable	q51_attribute4	"Importance of [Management ability]"
label variable	q51_attribute5	"Importance of [Social skills to related to people]"
label variable	q51_attribute6	"Importance of [Political awareness]"
label variable	q51_attribute7	"Importance of [Sense of public mission]"
label variable	q51_attribute8	"Importance of [Creativity]"
label variable	q52_statement1	"Agree with: [I fully understand what is expected of me as a planner in terms of integrity and ethical behaviour"
label variable	q52_statement2	"Agree with: [The organisation I work for rewards employees who exhibit ethical behaviour"
label variable	q53	"Are you subject to a professional code of conduct?"
label variable	q54_allanswers	"If you responded Yes to Question 53, which entities have promulgated a professional code of conduct to which you are subject? Check all that apply"
label variable	q55	"If you responded Yes to Question 53, how useful do you find the professional code of conduct?"
label variable	q56	"If you responded Yes to Question 53, why was or wasn't the professional code of conduct useful?"
label variable	q57	"Do planning associations have a role to play when it comes to addressing corruption and promoting integrity?"
label variable	q58_allanswers	"If you responded Yes to Question 57, what are the main functions the association should assume? Check all that apply"
label variable	q59_activity1	"Carry out: [Provide training on ethics and integrity for practicing planners]"
label variable	q59_activity2	"Carry out: [Develop and promote a good code of conduct]"
label variable	q59_activity3	"Carry out: [Support whistle-blowers]"
label variable	q59_activity4	"Carry out: [Discipline bad behaviour]"
label variable	q59_activity5	"Carry out: [Host discussions about values in planning and how to develop them further]"

compress

//Save stata 15
save "zaf-cois-2020-stata15.dta",replace

//Save csv
export delimited using "zaf-cois-2020-csv.csv", replace delimiter(";")

//Save stata 12
//To save the old version, string variables longer than 244 must be truncated
//This is only saved to obtain the metadata
//Users will not have access to the older version 
recast str244 q18 q23 q21_allanswers q27_allanswers q56 q58_allanswers,force
saveold "zaf-cois-2020-stata12.dta",replace version(12)
